@@ -94,7 +94,8 @@ class Futaba(Driver):
             # print('####', count, len(response_data))
             return len(response_data) == (8 + count)
 
-    def __get_checksum(self, data):
+    @staticmethod
+    def __get_checksum(data):
         """チェックサムを生成
 
         :param data:
@@ -106,6 +107,17 @@ class Futaba(Driver):
             checksum ^= data[i]
         return checksum
 
+    @staticmethod
+    def __check_sid(sid):
+        """Servo IDのレンジをチェック
+
+        :param sid:
+        :return:
+        """
+
+        if sid < 1 or sid > 127:
+            raise BadInputParametersException('sid: %d がレンジ外です。1から127のIDを設定してください。' % sid)
+
     def __generate_command(self, sid, addr, data=None, flag=0, count=1, length=None):
         """コマンド生成
 
@@ -263,11 +275,11 @@ class Futaba(Driver):
                 data = recv_data
 
         command = self.__generate_command(sid, address, flag=flag, count=0, length=length)
-        self.add_command_queue(command, recv_callback=temp_recv_callback)
+        self.add_command(command, recv_callback=temp_recv_callback)
 
         # コールバックが設定できていたら、コールバックに受信データを渡す
         if callback is None:
-            # X秒以内にサーボからデータを受信できたかをチェック
+            # 指定以内にサーボからデータを受信できたかをチェック
             start = time.time()
             while not is_received:
                 elapsed_time = time.time() - start
@@ -280,35 +292,6 @@ class Futaba(Driver):
         else:
             return True
 
-    def __async_wrapper(self, loop=None):
-        """async対応するための関数
-
-        :param loop:
-        :return:
-        """
-
-        if loop is None:
-            loop = asyncio.get_event_loop()
-
-        f = loop.create_future()
-
-        def callback(result):
-            loop.call_soon_threadsafe(
-                lambda: f.set_result(result)
-            )
-
-        return f, callback
-
-    def __check_sid(self, sid):
-        """Servo IDのレンジをチェック
-
-        :param sid:
-        :return:
-        """
-
-        if sid < 1 or sid > 127:
-            raise BadInputParametersException('sid: %d がレンジ外です。1から127のIDを設定してください。' % sid)
-
     def get_torque_enable(self, sid, callback=None):
         """トルクON取得
 
@@ -341,6 +324,45 @@ class Futaba(Driver):
         self.get_torque_enable(sid, callback=callback)
         return f
 
+    def ping(self, sid, callback=None):
+        """サーボにPINGを送る
+        FutabaにはPINGコマンドはないので、get_servo_idで代用。
+
+        :param sid:
+        :param callback:
+        :return: {
+            'model_no': bytearray (2bytes),
+            'version_firmware': int (1byte)
+        }
+        """
+
+        # TODO: model_noとversion_firmwareをreadで一気に取得する方式に変更
+
+        # サーボIDのチェック
+        self.__check_sid(sid)
+
+        if callback:
+            def inner_callback(_sid):
+                if callback:
+                    callback(_sid == sid)
+
+            self.get_servo_id(sid, callback=inner_callback)
+        else:
+            servo_id = self.get_servo_id(sid)
+            return sid == servo_id
+
+    def ping_async(self, sid, loop=None):
+        """サーボにPINGを送る async版
+
+        :param sid:
+        :param loop:
+        :return:
+        """
+
+        f, callback = self.__async_wrapper(loop)
+        self.ping(sid, callback=callback)
+        return f
+
     def set_torque_enable(self, on_off, sid):
         """トルクON/OFF設定
 
@@ -359,7 +381,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_TORQUE_ENABLE, [torque_data])
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_temperature(self, sid, callback=None):
         """温度取得（単位: ℃。おおよそ±3℃程度の誤差あり）
@@ -487,7 +509,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_GOAL_POSITION_L, [position_hex_l, position_hex_h])
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_current_position(self, sid, callback=None):
         """現在位置取得 (単位: 度)
@@ -619,7 +641,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_GOAL_TIME_L, [speed_hex_l, speed_hex_h])
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_pid_coefficient(self, sid, callback=None):
         """モータの制御係数を取得 (単位: %)
@@ -680,7 +702,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_PID_COEFFICIENT, [coef_hex])
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_max_torque(self, sid, callback=None):
         """最大トルク取得 (%)
@@ -738,7 +760,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_MAX_TORQUE, [torque_hex])
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_speed(self, sid, callback=None):
         """現在の回転速度を取得 (deg/s)
@@ -834,7 +856,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_SERVO_ID, [new_sid_hex])
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def save_rom(self, sid):
         """フラッシュROMに書き込む
@@ -850,7 +872,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_WRITE_FLASH_ROM, flag=0x40, count=0)
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_baud_rate(self, sid, callback=None):
         """通信速度を取得
@@ -906,7 +928,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_BAUD_RATE, [baud_rate_id_hex])
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_limit_cw_position(self, sid, callback=None):
         """右(時計回り)リミット角度の取得
@@ -965,7 +987,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_CW_ANGLE_LIMIT_L, [limit_position_hex_l, limit_position_hex_h])
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_limit_ccw_position(self, sid, callback=None):
         """左(反時計回り)リミット角度の取得
@@ -1025,7 +1047,7 @@ class Futaba(Driver):
                                           [limit_position_hex_l, limit_position_hex_h])
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_limit_temperature(self, sid, callback=None):
         """温度リミットの取得 (℃)
@@ -1093,7 +1115,7 @@ class Futaba(Driver):
         command = self.__generate_burst_command(self.ADDR_GOAL_POSITION_L, 3, vid_data)
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def get_burst_positions(self, sids, callback=None):
         """複数のサーボの現在のポジションを一気にリード
@@ -1129,7 +1151,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, self.ADDR_RESET_MEMORY, flag=self.FLAG4_RESET_MEMORY_MAP, count=0)
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def read(self, sid, address, length, callback=None):
         """データを読み込む
@@ -1183,7 +1205,7 @@ class Futaba(Driver):
         command = self.__generate_command(sid, address, data)
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
 
     def burst_read(self, sid_address_length, callback=None):
         """複数サーボから一括でデータ読み取り
@@ -1226,4 +1248,4 @@ class Futaba(Driver):
         command = self.__generate_burst_command(address, length, vid_data)
 
         # データ送信バッファに追加
-        self.add_command_queue(command)
+        self.add_command(command)
